@@ -20,9 +20,10 @@ int main (int argc, char **argv)
   gtk_init (&argc, &argv);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_widget_show (window);
   widget = cc_mouse_test_new ();
+  gtk_widget_show (widget);
   gtk_container_add (GTK_CONTAINER (window), widget);
-  gtk_widget_show_all (window);
 
   g_signal_connect (G_OBJECT (window), "delete-event", G_CALLBACK (delete_event_cb), NULL);
 
